==> jc-1.4.0.tar.gz: polyglot/main/Options.h <==
// public class polyglot.main.Options

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c588a9955b794e83 polyglot_main_Options

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Options_H_
#define _JC_polyglot_main_Options_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_main_Options$object;

// Typedefs
typedef struct _jc_polyglot_main_Options$sub_refs	_jc_polyglot_main_Options$sub_refs;
typedef struct _jc_polyglot_main_Options$sub_nonrefs	_jc_polyglot_main_Options$sub_nonrefs;
typedef struct _jc_polyglot_main_Options$refs	_jc_polyglot_main_Options$refs;
typedef struct _jc_polyglot_main_Options$nonrefs	_jc_polyglot_main_Options$nonrefs;
typedef struct _jc_polyglot_main_Options$object	_jc_polyglot_main_Options$object;

typedef struct _jc_polyglot_main_Options$fields_struct	_jc_polyglot_main_Options$fields_struct;
typedef const struct _jc_polyglot_main_Options$vmethods	_jc_polyglot_main_Options$vmethods;
typedef const struct _jc_polyglot_main_Options$vtable	_jc_polyglot_main_Options$vtable;
typedef const struct _jc_polyglot_main_Options$vtype	_jc_polyglot_main_Options$vtype;

// Class fields structure
struct _jc_polyglot_main_Options$fields_struct {
	struct _jc_polyglot_main_Options$object	*global;
};
extern _jc_polyglot_main_Options$fields_struct _jc_polyglot_main_Options$class_fields;

// Constructors
extern void _jc_polyglot_main_Options$method$_init$b68afe312166e950(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_main_Options$method$constructFullClasspath$d27b526b98cf1aec(_jc_env *, struct _jc_polyglot_main_Options$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_main_Options$method$constructPostCompilerClasspath$7c9c2f8de31d1211(_jc_env *, struct _jc_polyglot_main_Options$object *);
extern jint _jc_polyglot_main_Options$method$parseCommand$2e4a5685335d7508(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, jint, struct _jc_object *);
extern void _jc_polyglot_main_Options$method$parseCommandLine$dfb57731ca429af0(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, struct _jc_object *);
extern void _jc_polyglot_main_Options$method$setDefaultValues$7d3d97ff10c6aa68(_jc_env *, struct _jc_polyglot_main_Options$object *);
extern void _jc_polyglot_main_Options$method$usage$7be3a97038c76482(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_java_io_PrintStream$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_main_Options$method_info$constructFullClasspath$d27b526b98cf1aec;
extern _jc_method _jc_polyglot_main_Options$method_info$constructPostCompilerClasspath$7c9c2f8de31d1211;
extern _jc_method _jc_polyglot_main_Options$method_info$parseCommand$2e4a5685335d7508;
extern _jc_method _jc_polyglot_main_Options$method_info$parseCommandLine$dfb57731ca429af0;
extern _jc_method _jc_polyglot_main_Options$method_info$setDefaultValues$7d3d97ff10c6aa68;
extern _jc_method _jc_polyglot_main_Options$method_info$usage$7be3a97038c76482;

// Virtual methods structure
struct _jc_polyglot_main_Options$vmethods {
	struct _jc_java_lang_String$object	*(*constructFullClasspath$d27b526b98cf1aec)(_jc_env *, struct _jc_polyglot_main_Options$object *);
	struct _jc_java_lang_String$object	*(*constructPostCompilerClasspath$7c9c2f8de31d1211)(_jc_env *, struct _jc_polyglot_main_Options$object *);
	jint	(*parseCommand$2e4a5685335d7508)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, jint, struct _jc_object *);
	void	(*parseCommandLine$dfb57731ca429af0)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, struct _jc_object *);
	void	(*setDefaultValues$7d3d97ff10c6aa68)(_jc_env *, struct _jc_polyglot_main_Options$object *);
	void	(*usage$7be3a97038c76482)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_java_io_PrintStream$object *);
};

// Vtable
struct _jc_polyglot_main_Options$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Options$vmethods	polyglot_main_Options;
};

// Vtype
struct _jc_polyglot_main_Options$vtype {
	_jc_type			type;
	_jc_polyglot_main_Options$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Options$sub_refs {
	struct _jc_object	*extension;
	struct _jc_object	*source__5fpath;
	struct _jc_java_io_File$object	*output__5fdirectory;
	struct _jc_java_lang_String$object	*default__5fclasspath;
	struct _jc_java_lang_String$object	*classpath;
	struct _jc_java_lang_String$object	*bootclasspath;
	struct _jc_java_lang_String$object	*source__5fext;
	struct _jc_java_lang_String$object	*output__5fext;
	struct _jc_java_lang_String$object	*post__5fcompiler;
	struct _jc_object	*dump__5fast;
	struct _jc_object	*disable__5fpasses;
};

// Reference instance fields (object)
struct _jc_polyglot_main_Options$refs {
    _jc_polyglot_main_Options$sub_refs	polyglot_main_Options;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Options$sub_nonrefs {
	jint	error__5fcount;
	jboolean	assertions;
	jboolean	output__5fstdout;
	jint	output__5fwidth;
	jboolean	fully__5fqualified__5fnames;
	jboolean	serialize__5ftype__5finfo;
	jboolean	keep__5foutput__5ffiles;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Options$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Options$sub_nonrefs	polyglot_main_Options;
};

// Object instance structure
struct _jc_polyglot_main_Options$object {
	_jc_polyglot_main_Options$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Options$vtype	*vtype;
	_jc_polyglot_main_Options$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Options$vtype _jc_polyglot_main_Options$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Options, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Options$class_object;

#endif	/* _JC_polyglot_main_Options_H_ */

==> jc-1.4.6.tar.gz: polyglot/main/Options.h <==
// public class polyglot.main.Options

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c588a9955b794e83 polyglot_main_Options

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_main_Options_H_
#define _JC_polyglot_main_Options_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Set$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_main_Options$object;

// Typedefs
typedef struct _jc_polyglot_main_Options$sub_refs	_jc_polyglot_main_Options$sub_refs;
typedef struct _jc_polyglot_main_Options$sub_nonrefs	_jc_polyglot_main_Options$sub_nonrefs;
typedef struct _jc_polyglot_main_Options$refs	_jc_polyglot_main_Options$refs;
typedef struct _jc_polyglot_main_Options$nonrefs	_jc_polyglot_main_Options$nonrefs;
typedef struct _jc_polyglot_main_Options$object	_jc_polyglot_main_Options$object;

typedef struct _jc_polyglot_main_Options$fields_struct	_jc_polyglot_main_Options$fields_struct;
typedef const struct _jc_polyglot_main_Options$vmethods	_jc_polyglot_main_Options$vmethods;
typedef const struct _jc_polyglot_main_Options$vtable	_jc_polyglot_main_Options$vtable;
typedef const struct _jc_polyglot_main_Options$vtype	_jc_polyglot_main_Options$vtype;

// Class fields structure
struct _jc_polyglot_main_Options$fields_struct {
	struct _jc_polyglot_main_Options$object	*global;
};
extern _jc_polyglot_main_Options$fields_struct _jc_polyglot_main_Options$class_fields;

// Constructors
extern void _jc_polyglot_main_Options$method$_init$b68afe312166e950(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_main_Options$method$constructFullClasspath$d27b526b98cf1aec(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_main_Options$method$constructPostCompilerClasspath$7c9c2f8de31d1211(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_main_Options$method$parseCommand$2e4a5685335d7508(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, jint, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Options$method$parseCommandLine$dfb57731ca429af0(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Options$method$setDefaultValues$7d3d97ff10c6aa68(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_main_Options$method$usage$7be3a97038c76482(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_main_Options$method_info$constructFullClasspath$d27b526b98cf1aec;
extern _jc_method _jc_polyglot_main_Options$method_info$constructPostCompilerClasspath$7c9c2f8de31d1211;
extern _jc_method _jc_polyglot_main_Options$method_info$parseCommand$2e4a5685335d7508;
extern _jc_method _jc_polyglot_main_Options$method_info$parseCommandLine$dfb57731ca429af0;
extern _jc_method _jc_polyglot_main_Options$method_info$setDefaultValues$7d3d97ff10c6aa68;
extern _jc_method _jc_polyglot_main_Options$method_info$usage$7be3a97038c76482;

// Virtual methods structure
struct _jc_polyglot_main_Options$vmethods {
	struct _jc_java_lang_String$object	*(*constructFullClasspath$d27b526b98cf1aec)(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*constructPostCompilerClasspath$7c9c2f8de31d1211)(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
	jint	(*parseCommand$2e4a5685335d7508)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, jint, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*parseCommandLine$dfb57731ca429af0)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_object_array *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*setDefaultValues$7d3d97ff10c6aa68)(_jc_env *, struct _jc_polyglot_main_Options$object *) _JC_JCNI_ATTR;
	void	(*usage$7be3a97038c76482)(_jc_env *, struct _jc_polyglot_main_Options$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_main_Options$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_main_Options$vmethods	polyglot_main_Options;
};

// Vtype
struct _jc_polyglot_main_Options$vtype {
	_jc_type			type;
	_jc_polyglot_main_Options$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_main_Options$sub_refs {
	struct _jc_object	*extension;
	struct _jc_object	*source__5fpath;
	struct _jc_java_io_File$object	*output__5fdirectory;
	struct _jc_java_lang_String$object	*default__5fclasspath;
	struct _jc_java_lang_String$object	*classpath;
	struct _jc_java_lang_String$object	*bootclasspath;
	struct _jc_java_lang_String$object	*source__5fext;
	struct _jc_java_lang_String$object	*output__5fext;
	struct _jc_java_lang_String$object	*post__5fcompiler;
	struct _jc_object	*dump__5fast;
	struct _jc_object	*disable__5fpasses;
};

// Reference instance fields (object)
struct _jc_polyglot_main_Options$refs {
    _jc_polyglot_main_Options$sub_refs	polyglot_main_Options;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_main_Options$sub_nonrefs {
	jint	error__5fcount;
	jboolean	assertions;
	jboolean	output__5fstdout;
	jint	output__5fwidth;
	jboolean	fully__5fqualified__5fnames;
	jboolean	serialize__5ftype__5finfo;
	jboolean	keep__5foutput__5ffiles;
};

// Non-reference instance fields (object)
struct _jc_polyglot_main_Options$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_main_Options$sub_nonrefs	polyglot_main_Options;
};

// Object instance structure
struct _jc_polyglot_main_Options$object {
	_jc_polyglot_main_Options$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_main_Options$vtype	*vtype;
	_jc_polyglot_main_Options$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_main_Options$vtype _jc_polyglot_main_Options$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_main_Options, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_main_Options$class_object;

#endif	/* _JC_polyglot_main_Options_H_ */
